#!/bin/sh 
########################################################################
#  Copyright 2002 M Square Inc. All Rights Reserved 
########################################################################
#
########################################################################
#
#
#   Unix Shell Script:
#
#   Upgrading ParaChat Server 3.0 or below to ParaChat 4.0
#
#######################################################################

licensepath=config/paraserver.lic

if [ "$#" -ne 1 ] 
then
  echo "Incorrect number of arguments."
  echo "Usage:"
  echo "$0 ParaChat300_server_absolute_path"
  echo " "
  echo "For example: $0 /home/chat/ParaChat300"
  echo "if there is any space in the path of ParaChat 3.0,"
  echo "You need to put double quote around the path."
  exit 2
fi

###################################################
#
# Checking Config of Version 3.0 and Version 4.0
#
###################################################

oldpath=$1
newpath=`pwd`
echo "You entered ParaChat version 3.0 path as: $oldpath"
echo "Version 4.0 path is: $newpath"
echo "Checking version 3.0 license file."

if [ -f "$oldpath/$licensepath" ]
then
  echo "Found version 3.0 license file. Continue."
else
  echo "Cannot locate version 3.0 license file:$oldpath/$licensepath"
  echo "Please check your ParaChat server 3.0 path and try again."
  exit 3
fi

if [ -f "$oldpath/config/pchatd.conf" ]
then
  echo "Found version 3.0 config file. Continue."
else
  echo "Cannot locate version 3.0 config file:$oldpath/config/pchatd.conf"
  echo "Please check your ParaChat server 3.0 path and try again."
  exit 4
fi

echo "Checking if version 4.0 has completed."
if [ -d "./rooms" -a -d "./users" ]
then
  echo "Found ./users and ./rooms directories. Continue."
else
  echo "###Error: users or rooms directories for ParaChat 4.0 not found."
  echo "ParaChat 4.0 installation has not completed."
  echo "ParaChat 4.0 has to be installed before upgrade."
  echo "Run ./install.sh to install ParaChat400."
  exit 5
fi

# backup current 4.0 config file if it is possible.
if [ ! -f "./config/pchatd.conf.40" ]
then
  echo "backing up current pchatd.conf file as pchatd.conf.40"
  cp ./config/pchatd.conf ./config/pchatd.conf.40
else
  echo "pchatd.conf.40 already backed up. Continue."
fi


#######################################################
#
# Copy data from v3.0 server
#
#######################################################


##
# copy logs
##

echo "Copying logs directory..."
if [ ! -d ./logs ]
then
  mkdir ./logs
fi

if cp -r -f $oldpath/logs/* "$newpath/logs/"
then
  echo "transcript log files copied."
else
  echo "###Warning: logs directory cannot be copied."
fi

##
# copy radata
##
echo "Copying radata directory..."
if [ ! -d ./radata ]
then
  mkdir ./radata
fi

if [ ! -d $oldpath/radata ]
then
  echo "No radata found. skipping."
else
      if cp -r -f $oldpath/radata/* "$newpath/radata/"
      then
         echo "radata copied."
      else
         echo "###Warning: radata directory cannot be copied."
      fi
fi


##
# copy rooms
##

echo "Copying rooms directory..."
if cp -r -f $oldpath/rooms/* "$newpath/rooms/"
then
  echo "All chat room profiles copied."
else
  echo "###Error: failed to copy rooms: $oldpath/rooms/"
fi


##
# copy users
##

echo "Copying users directory..."
if cp -r -f $oldpath/users/* "$newpath/users/"
then
  echo "All user profiles copied."
else
  echo "###Error: failed to copy users: $oldpath/users/"
fi


##
# copy ad scripts
##

echo "Copying ad scripts directory..."
adscripts="httpd/pchat/classes/scripts"

if cp -r -f $oldpath/$adscripts/* "$newpath/$adscripts/"
then
  echo "All ad scripts copied."
else
  echo "###Error: failed to copy ad scripts: $oldpath/$adscripts/"
fi


##
# copy ad images
##

echo "Copying ad images directory..."
adimages="httpd/pchat/classes/images"

if cp -r -f $oldpath/$adimages/* "$newpath/$adimages/"
then
  echo "All ad images copied."
else
  echo "###Error: failed to copy ad imagess: $oldpath/$adimages/"
fi


##
# Copy config file of ParaChat 3.0
##

oldconf="$oldpath/config/pchatd.conf"
if cp -f $oldconf $newpath/config/
then
  echo "verions 3.0 config file copied."
else
  echo "###Error: version 3.0 config file cannot be copied:$oldconf"
fi


##
# Modify config file.
##

newconf="$newpath/config/pchatd.conf"
tempfile="$newpath/config/pchatd.conf_temp"
backupconf="$newpath/config/pchatd.conf.30"

echo "stripping old config using, $tempfile"
cp $newconf $backupconf
sed '/paralynx\.plugin\.chatpanel\.clientroot=/d' $newconf > $tempfile
mv $tempfile $newconf
sed '/pchatd\.home=/d' $newconf > $tempfile
mv $tempfile $newconf

##
# add new path to config file
##
echo "Updating config file..."
echo "## appended by v4.0 upgrade." >> $newconf
echo "paralynx.plugin.chatpanel.clientroot=$newpath/httpd/pchat/classes" >> $newconf
echo "pchatd.home=$newpath" >> $newconf

echo "####################################################################"
echo "# You should have already received your new version 4.0 license."
echo "# You need to update \"paraserver.lic\" following the instructions."
echo "####################################################################"


echo ""
echo "Upgrading to ParaChat 4.0 completed."
echo ""

